==> haskell-boring-0.2.1-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-boring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 boring
version:              0.2.1
visibility:           public
id:                   boring-0.2.1-Icfsg6aSH6SpFFKOquZU
key:                  boring-0.2.1-Icfsg6aSH6SpFFKOquZU
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/boring
synopsis:             Boring and Absurd types
description:
    * @Boring@ types are isomorphic to @()@.

    * @Absurd@ types are isomorphic to @Void@.

    See [What does () mean in Haskell -answer by Conor McBride](https://stackoverflow.com/questions/33112439/what-does-mean-in-haskell/33115522#33115522)

category:             Data
abi:                  c6fb68505cf7daf19c4e24844055828e
exposed:              True
exposed-modules:      Data.Boring
import-dirs:          /usr/lib/ghc-9.2.8/site-local/boring-0.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/boring-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boring
hs-libraries:         HSboring-0.2.1-Icfsg6aSH6SpFFKOquZU
depends:
    base-4.16.4.0 tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-boring/html/boring.haddock
haddock-html:         /usr/share/doc/haskell-boring/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-boring-0.2.1-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-boring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 boring
version:              0.2.1
visibility:           public
id:                   boring-0.2.1-4ay7NZ1mR0V485tuSNtr0u
key:                  boring-0.2.1-4ay7NZ1mR0V485tuSNtr0u
license:              BSD-3-Clause
copyright:            (c) 2017-2021 Oleg Grenrus
maintainer:           Oleg.Grenrus <oleg.grenrus@iki.fi>
author:               Oleg Grenrus <oleg.grenrus@iki.fi>
homepage:             https://github.com/phadej/boring
synopsis:             Boring and Absurd types
description:
    * @Boring@ types are isomorphic to @()@.

    * @Absurd@ types are isomorphic to @Void@.

    See [What does () mean in Haskell -answer by Conor McBride](https://stackoverflow.com/questions/33112439/what-does-mean-in-haskell/33115522#33115522)

category:             Data
abi:                  e0b803032b1df1363b4d7b49db3f9072
exposed:              True
exposed-modules:      Data.Boring
import-dirs:          /usr/lib/ghc-9.2.8/site-local/boring-0.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/boring-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-boring
hs-libraries:         HSboring-0.2.1-4ay7NZ1mR0V485tuSNtr0u
depends:
    base-4.16.4.0 tagged-0.8.9-KXBukbFHRBNBMyyfjfj7aP
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-boring/html/boring.haddock
haddock-html:         /usr/share/doc/haskell-boring/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
